==> seedsui-react-5.5.91.tgz: package/lib/Input/Range/index.js <==
var _excluded = ["value", "min", "max", "step", "readOnly", "disabled", "inputProps", "tooltipProps", "onChange"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react';
import Instance from "./instance";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Range = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$value = _ref.value,
      value = _ref$value === void 0 ? 0 : _ref$value,
      _ref$min = _ref.min,
      min = _ref$min === void 0 ? 0 : _ref$min,
      _ref$max = _ref.max,
      max = _ref$max === void 0 ? 100 : _ref$max,
      _ref$step = _ref.step,
      step = _ref$step === void 0 ? 1 : _ref$step,
      readOnly = _ref.readOnly,
      disabled = _ref.disabled,
      _ref$inputProps = _ref.inputProps,
      inputProps = _ref$inputProps === void 0 ? {} : _ref$inputProps,
      _ref$tooltipProps = _ref.tooltipProps,
      tooltipProps = _ref$tooltipProps === void 0 ? {} : _ref$tooltipProps,
      onChange = _ref.onChange,
      props = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  var inputRef = useRef(null);
  var tooltipRef = useRef(null);
  var instance = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      inputDOM: inputRef.current,
      tooltipDOM: tooltipRef.current,
      instance: instance.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInputDOM: function getInputDOM() {
        return inputRef.current;
      },
      getTooltipDOM: function getTooltipDOM() {
        return tooltipRef.current;
      },
      getInstance: function getInstance() {
        return instance.current;
      }
    };
  });
  useEffect(function () {
    if (instance.current) return;
    initInstance();
  }, []); // eslint-disable-line
  // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    instance.current.params.onChange = handleChange;
  }

  function initInstance() {
    instance.current = new Instance(rootRef.current, {
      onChange: handleChange
    });
  }

  function handleChange() {
    var newValue = inputRef.current.value;
    if (newValue) newValue = Number(newValue || 0);

    if (onChange) {
      onChange(newValue);
    }
  }

  return /*#__PURE__*/_jsxs("div", _objectSpread(_objectSpread({
    ref: rootRef
  }, props), {}, {
    className: "input-range".concat(props.className ? ' ' + props.className : ''),
    children: [/*#__PURE__*/_jsx("input", _objectSpread(_objectSpread({
      ref: inputRef
    }, inputProps), {}, {
      readOnly: readOnly,
      disabled: disabled,
      type: "range",
      className: "input-range-input".concat(inputProps.className ? ' ' + inputProps.className : ''),
      min: min,
      max: max,
      step: step,
      defaultValue: value
    })), /*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({
      ref: tooltipRef
    }, tooltipProps), {}, {
      className: "input-range-tooltip".concat(tooltipProps.className ? ' ' + tooltipProps.className : ''),
      children: value
    }))]
  }));
});
export default Range;

==> seedsui-react-5.5.92.tgz: package/lib/Input/Range/index.js <==
var _excluded = ["value", "min", "max", "step", "readOnly", "disabled", "inputProps", "tooltipProps", "onChange"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react';
import Instance from "./instance";
var Range = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$value = _ref.value,
      value = _ref$value === void 0 ? 0 : _ref$value,
      _ref$min = _ref.min,
      min = _ref$min === void 0 ? 0 : _ref$min,
      _ref$max = _ref.max,
      max = _ref$max === void 0 ? 100 : _ref$max,
      _ref$step = _ref.step,
      step = _ref$step === void 0 ? 1 : _ref$step,
      readOnly = _ref.readOnly,
      disabled = _ref.disabled,
      _ref$inputProps = _ref.inputProps,
      inputProps = _ref$inputProps === void 0 ? {} : _ref$inputProps,
      _ref$tooltipProps = _ref.tooltipProps,
      tooltipProps = _ref$tooltipProps === void 0 ? {} : _ref$tooltipProps,
      onChange = _ref.onChange,
      props = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  var inputRef = useRef(null);
  var tooltipRef = useRef(null);
  var instance = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      inputDOM: inputRef.current,
      tooltipDOM: tooltipRef.current,
      instance: instance.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      },
      getInputDOM: function getInputDOM() {
        return inputRef.current;
      },
      getTooltipDOM: function getTooltipDOM() {
        return tooltipRef.current;
      },
      getInstance: function getInstance() {
        return instance.current;
      }
    };
  });
  useEffect(function () {
    if (instance.current) return;
    initInstance();
  }, []); // eslint-disable-line
  // 更新句柄, 防止synchronization模式, 每次组件在render的时候都生成上次render的state、function、effects

  if (instance.current) {
    instance.current.params.onChange = handleChange;
  }

  function initInstance() {
    instance.current = new Instance(rootRef.current, {
      onChange: handleChange
    });
  }

  function handleChange() {
    var newValue = inputRef.current.value;
    if (newValue) newValue = Number(newValue || 0);

    if (onChange) {
      onChange(newValue);
    }
  }

  return /*#__PURE__*/React.createElement("div", _extends({
    ref: rootRef
  }, props, {
    className: "input-range".concat(props.className ? ' ' + props.className : '')
  }), /*#__PURE__*/React.createElement("input", _extends({
    ref: inputRef
  }, inputProps, {
    readOnly: readOnly,
    disabled: disabled,
    type: "range",
    className: "input-range-input".concat(inputProps.className ? ' ' + inputProps.className : ''),
    min: min,
    max: max,
    step: step,
    defaultValue: value
  })), /*#__PURE__*/React.createElement("div", _extends({
    ref: tooltipRef
  }, tooltipProps, {
    className: "input-range-tooltip".concat(tooltipProps.className ? ' ' + tooltipProps.className : '')
  }), value));
});
export default Range;
